aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/MC/MCMachOSymbolFlags.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/MC/MCMachOSymbolFlags.h')
-rw-r--r--include/llvm/MC/MCMachOSymbolFlags.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/llvm/MC/MCMachOSymbolFlags.h b/include/llvm/MC/MCMachOSymbolFlags.h
index 696436d..71f01fa 100644
--- a/include/llvm/MC/MCMachOSymbolFlags.h
+++ b/include/llvm/MC/MCMachOSymbolFlags.h
@@ -19,9 +19,9 @@
// the correct relocation information.
namespace llvm {
- /// SymbolFlags - We store the value for the 'desc' symbol field in the lowest
- /// 16 bits of the implementation defined flags.
- enum SymbolFlags { // See <mach-o/nlist.h>.
+ /// MachOSymbolFlags - We store the value for the 'desc' symbol field in the
+ /// lowest 16 bits of the implementation defined flags.
+ enum MachOSymbolFlags { // See <mach-o/nlist.h>.
SF_DescFlagsMask = 0xFFFF,
// Reference type flags.